@@ -8,9 +8,9 @@ import pandas as pd
 _cache_dir = pathlib.Path(".statfin_cache")
 
 
-def _cache_paths(id: str) -> tuple[pathlib.Path, pathlib.Path]:
+def _cache_paths(name: str) -> tuple[pathlib.Path, pathlib.Path]:
     _cache_dir.mkdir(parents=True, exist_ok=True)
-    return _cache_dir / f"{id}.meta", _cache_dir / f"{id}.df"
+    return _cache_dir / f"{name}.meta", _cache_dir / f"{name}.df"
 
 
 def clear() -> None:
@@ -23,24 +23,24 @@ def clear() -> None:
         pass
 
 
-def set_dir(dir: str | pathlib.Path) -> None:
+def set_dir(dirname: str | pathlib.Path) -> None:
     """
     Set the parent directory for cache files
     """
-    _cache_dir = pathlib.Path(dir)
+    _cache_dir = pathlib.Path(dirname)
 
 
-def load(id: str, fingerprint: dict) -> pd.DataFrame | None:
+def load(name: str, fingerprint: dict) -> pd.DataFrame | None:
     """
-    Load a dataframe from the given cache id
+    Load a dataframe from the given cache name
 
     There must also be a {path}.meta file which contains a "fingerprint" JSON
     for the dataframe. If not, the cached dataframe is rejected (and will
     probably be overwritten).
     """
     try:
-        meta_path, df_path = _cache_paths(id)
-        with open(meta_path, "r") as f:
+        meta_path, df_path = _cache_paths(name)
+        with open(meta_path, "r", encoding="utf-8") as f:
             j = json.load(f)
             if j != fingerprint:
                 return None
@@ -49,11 +49,11 @@ def load(id: str, fingerprint: dict) -> pd.DataFrame | None:
         return None
 
 
-def store(id: str, df: pd.DataFrame, fingerprint: dict) -> None:
+def store(name: str, df: pd.DataFrame, fingerprint: dict) -> None:
     """
     Cache a dataframe to the given path
     """
-    meta_path, df_path = _cache_paths(id)
-    with open(meta_path, "w") as f:
+    meta_path, df_path = _cache_paths(name)
+    with open(meta_path, "w", encoding="utf-8") as f:
         f.write(json.dumps(fingerprint))
     df.to_pickle(df_path)
